<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=pl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Polski [pl]',
	'0_liste' => 'spip-dev@rezo.net',
	'0_mainteneur' => 'd.paszkiewicz@ekstenso.com',

	// A
	'access_interface_graphique' => 'Powrót do pełnego interfejsu graficznego',
	'access_mode_texte' => 'Uproszczony interfejs - tryb tekstowy',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modyfikuj artykuł',
	'admin_modifier_auteur' => 'Modyfikuj autora',
	'admin_modifier_breve' => 'Modyfikuj news',
	'admin_modifier_mot' => 'Modyfikuj słowo kluczowe',
	'admin_modifier_rubrique' => 'Modyfikuj dział',
	'admin_recalculer' => 'Odśwież ',
	'afficher_calendrier' => 'Wyświetl kalendarz',
	'afficher_trad' => 'pokaż przekłady',
	'alerte_maj_impossible' => '<b>Uwaga!</b> Uaktualnienie bazy danych SQL do wersji @version@ jest nie możliwe. Powodem jest prawdopodobnie brak uprawnień do modyfikacji bazy danych. Skontaktuj się z administratorem lub firmą hostingową.',
	'alerte_modif_info_concourante' => 'UWAGA: Ta informacja była zmieniana w innym miejscu. Obecna wartość to:Cette information a été modifiée par ailleurs. La valeur actuelle est :',
	'analyse_xml' => 'Analiza XML',
	'annuler' => 'Anuluj',
	'antispam_champ_vide' => 'Pozostaw puste:',
	'articles_recents' => 'Najnowsze artykuły',
	'avis_archive_incorrect' => 'ten plik archiwalny nie należy do SPIP',
	'avis_archive_invalide' => 'plik archiwalny jest nieprawidłowy',
	'avis_attention' => 'UWAGA !',
	'avis_champ_incorrect_type_objet' => 'Nieprawiłowa nazwa pola @name@ dla obiektu typu @type@',
	'avis_colonne_inexistante' => 'Kolumna @col@ nie istnieje',
	'avis_erreur' => 'Błąd: zobacz poniżej’;',
	'avis_erreur_connexion' => 'Błąd połączenia',
	'avis_erreur_cookie' => 'problem z cookie',
	'avis_erreur_fonction_contexte' => 'Błąd programistyczny. Ta funkcja nie powinna być wywoływana w tym kontekście.',
	'avis_erreur_mysql' => 'Błąd SQL',
	'avis_erreur_sauvegarde' => 'Błąd archiwizacji (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Problem z dostępem do stron administracyjnych',

	// B
	'barre_a_accent_grave' => 'Wstaw dużą literę A z akcentem grave',
	'barre_aide' => 'Użyj skrótów typograficznych do ulepszenia layoutu',
	'barre_e_accent_aigu' => 'Wstaw dużą literę E z akcentem acute',
	'barre_eo' => 'Wstaw ligaturę oe',
	'barre_eo_maj' => 'Wstaw dużą ligaturę EO',
	'barre_euro' => 'Umieść symbol €€',
	'barre_gras' => 'Wstaw w {{boldzie}}',
	'barre_guillemets' => 'Umieść w "cudzysłowie"',
	'barre_guillemets_simples' => 'Umieść w innym “cudzysłowie”',
	'barre_intertitre' => 'Przekształć w {{{śródtytuł}}}',
	'barre_italic' => 'Wstaw w {italiku}',
	'barre_lien' => 'Zmień w [hiperłącze->http://...]',
	'barre_lien_input' => 'Proszę wpisać cel hiperłącza (może to być URL internetowy w formie http://www.mysite.com lub po prostu numer artykułu na tej stronie).',
	'barre_note' => 'Zmień w [[Przypis]]',
	'barre_paragraphe' => 'Utwórz paragraf',
	'barre_quote' => '<quote>Zacytuj wiadomość</quote>',
	'bouton_changer' => 'Zatwierdź',
	'bouton_chercher' => 'Szukaj',
	'bouton_choisir' => 'Wybierz',
	'bouton_deplacer' => 'Przenieś',
	'bouton_download' => 'Ściągnij',
	'bouton_enregistrer' => 'Zapisz',
	'bouton_radio_desactiver_messagerie_interne' => 'Dezaktywuj pocztę wewnętrzną',
	'bouton_radio_envoi_annonces' => 'Wyślij ogłoszenia redakcyjne',
	'bouton_radio_non_envoi_annonces' => 'Nie wysyłaj żadnych zawiadomień',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Nie wysyłaj najnowszej listy newsów',
	'bouton_recharger_page' => 'ponownie załaduj tę stronę',
	'bouton_telecharger' => 'Załaduj',
	'bouton_upload' => 'Załaduj',
	'bouton_valider' => 'Zatwierdź',

	// C
	'cal_apresmidi' => 'popołudniu',
	'cal_jour_entier' => 'cały dzień',
	'cal_matin' => 'rano',
	'cal_par_jour' => 'wg dni',
	'cal_par_mois' => 'wg miesięcy',
	'cal_par_semaine' => 'wg tygodni',
	'choix_couleur_interface' => 'kolor',
	'choix_interface' => 'wybór interfejsu',
	'colonne' => 'Kolumna',
	'confirm_changer_statut' => 'Uwaga, czy na pewno chcesz zmienić status tego elementu ? Kontynuować ?',
	'correcte' => 'poprawna',

	// D
	'date_aujourdhui' => 'dziś',
	'date_avant_jc' => 'P.N.E.',
	'date_dans' => 'w @delai@',
	'date_de_mois_1' => '@j@ stycznia',
	'date_de_mois_10' => '@j@ października',
	'date_de_mois_11' => '@j@ listopada',
	'date_de_mois_12' => '@j@ grudnia',
	'date_de_mois_2' => '@j@ lutego',
	'date_de_mois_3' => '@j@ marca',
	'date_de_mois_4' => '@j@ kwietnia',
	'date_de_mois_5' => '@j@ maja',
	'date_de_mois_6' => '@j@ czerwca',
	'date_de_mois_7' => '@j@ lipca',
	'date_de_mois_8' => '@j@ sierpnia',
	'date_de_mois_9' => '@j@ września',
	'date_demain' => 'jutro',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ o @heure@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => '@date@ @nomjour@ ',
	'date_heures' => 'godziny',
	'date_hier' => 'wczoraj',
	'date_il_y_a' => 'jest @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Niedziela',
	'date_jour_1_abbr' => 'nie.',
	'date_jour_1_initiale' => 'n.',
	'date_jour_2' => 'Poniedziałek',
	'date_jour_2_abbr' => 'pon.',
	'date_jour_2_initiale' => 'p.',
	'date_jour_3' => 'Wtorek',
	'date_jour_3_abbr' => 'wto.',
	'date_jour_3_initiale' => 'w.',
	'date_jour_4' => 'Środa',
	'date_jour_4_abbr' => 'śro.',
	'date_jour_4_initiale' => 'ś.',
	'date_jour_5' => 'Czwartek',
	'date_jour_5_abbr' => 'czw.',
	'date_jour_5_initiale' => 'c.',
	'date_jour_6' => 'Piątek',
	'date_jour_6_abbr' => 'pią.',
	'date_jour_6_initiale' => 'p.',
	'date_jour_7' => 'Sobota',
	'date_jour_7_abbr' => 'sob.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'dni',
	'date_minutes' => 'minuty',
	'date_mois' => 'miesiąc',
	'date_mois_1' => 'Styczeń',
	'date_mois_10' => 'Październik',
	'date_mois_10_abbr' => 'paźdź.',
	'date_mois_11' => 'Listopad',
	'date_mois_11_abbr' => 'list.',
	'date_mois_12' => 'Grudzień',
	'date_mois_12_abbr' => 'gru.',
	'date_mois_1_abbr' => 'sty.',
	'date_mois_2' => 'Luty',
	'date_mois_2_abbr' => 'lut.',
	'date_mois_3' => 'Marzec',
	'date_mois_3_abbr' => 'mar.',
	'date_mois_4' => 'Kwiecień',
	'date_mois_4_abbr' => 'kw.',
	'date_mois_5' => 'Maj',
	'date_mois_5_abbr' => 'maj',
	'date_mois_6' => 'Czerwiec',
	'date_mois_6_abbr' => 'czer.',
	'date_mois_7' => 'Lipiec',
	'date_mois_7_abbr' => 'lip.',
	'date_mois_8' => 'Sierpień',
	'date_mois_8_abbr' => 'sie.',
	'date_mois_9' => 'Wrzesień',
	'date_mois_9_abbr' => 'wrz.',
	'date_saison_1' => 'zima',
	'date_saison_2' => 'wiosna',
	'date_saison_3' => 'lato',
	'date_saison_4' => 'jesień',
	'date_secondes' => 'sekundy',
	'date_semaines' => 'tygodnie',
	'date_un_mois' => 'miesiące',
	'date_une_heure' => 'godzina',
	'date_une_minute' => 'minuta',
	'date_une_seconde' => 'sekunda',
	'date_une_semaine' => 'tydzień',
	'dirs_commencer' => ' w celu rzeczywistego rozpoczęcia instalacji',
	'dirs_preliminaire' => 'Wstęp: <b>Ustawienia pozwoleń dostępu</b>',
	'dirs_probleme_droits' => 'Problem z prawami dostępu',
	'dirs_repertoires_absents' => '<p><b>Następujące katalogi nie zostały odnalezione :</b></p> <ul>@bad_dirs@.</ul> 
  <p>Możliwe, że powodem tego jest nazwa, w której pomylone zostały duże i małe litery.
  Sprawdź nazwy pod względem małych i dużych liter.
  Jeśli rzeczywiście wielkość liter jest różna, zmień nazwy katalogów za pomocą dowolnego programu FTP
  <p>Po wykonaniu tej operacji będziesz mógł',
	'dirs_repertoires_suivants' => '<p><b>Następujące katalogi nie są skonfigurowane do zapisu :</b></p> <ul>@bad_dirs@.</ul> 
  <p>Aby temu zapobiec, skorzystaj z klienta FTP i ureguluj konieczne prawa dostępu
  do tych katalogów. Procedura jest wytłumaczona od A-Z w przewodniku instalacji.
  <p>Kiedy dokonasz koniecznych zmian, będziesz mógł',
	'double_occurrence' => 'Podwójne wystąpienie @balise@',

	// E
	'en_cours' => 'w trakcie',
	'envoi_via_le_site' => 'Wyślij ze strony',
	'erreur' => 'Błąd',
	'erreur_balise_non_fermee' => 'ostatni znacznik nie jest zamknięty :',
	'erreur_texte' => 'błąd/błędy',
	'etape' => 'Etap',

	// F
	'fichier_introuvable' => 'Plik @fichier@ nie odnaleziony',
	'form_auteur_confirmation' => 'Potwierdź swój e-mail',
	'form_auteur_email_modifie' => 'Twój adres e-mail został zmieniony.',
	'form_auteur_envoi_mail_confirmation' => 'Mail z potwierdzeniem został wysłany na adres @email@. Prosimy o kliknięcie w link, przesłany w e-mailu aby zatwierdzić adres e-mail.',
	'form_auteur_mail_confirmation' => 'Dzień dobry,

Uruchomiłeś procedurę zmiany adresu e-mail.
Aby zatwierdzić nowy adres, wystarczy wejść pod podany niżej link,
jeśli tego nie uczynisz próba zmiany adresu zostanie anulowana:

    @url@
',
	'form_deja_inscrit' => 'Jesteś już zarejestrowany.',
	'form_email_non_valide' => 'Twój adres e-mail nie jest prawidłowy.',
	'form_forum_access_refuse' => 'Nie masz już dostępu do tej strony.',
	'form_forum_bonjour' => 'Witaj @nom@,',
	'form_forum_confirmer_email' => 'Aby zatwierdzić Twój adres e-mail, kliknij w ten link: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Ten adres e-mail jest już zarejestrowany, wskutek czego nie możesz używać swojego zwykłego hasła.',
	'form_forum_identifiant_mail' => 'Twój nowy identyfikator został właśnie wysłany do Ciebie e-mailem.',
	'form_forum_identifiants' => 'Osobista identyfikacja',
	'form_forum_indiquer_nom_email' => 'Wpisz tutaj swoje nazwisko i adres e-mail. Wkrótce otrzymasz e-mailem swój osobisty identyfikator.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(to jest wiadomość automatyczna)',
	'form_forum_pass' => 'hasło:',
	'form_forum_probleme_mail' => 'Problem z pocztą: Twój identyfikator nie może zostać wysłany.',
	'form_forum_voici1' => 'Oto Twóje dane, które pozwolą Ci wziąć udział w rozwoju serwisu
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Oto Twój identyfikator do proponowania artykułów w
serwisie "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Proszę wpisać swój adres e-mail.',
	'form_indiquer_nom' => 'Proszę wpisać swoje nazwisko.',
	'form_indiquer_nom_site' => 'Proszę wpisać nazwę swoich stron\\y.',
	'form_pet_deja_enregistre' => 'Ta strona jest już zarejestrowana',
	'form_pet_signature_pasprise' => 'Twój podpis został zlekceważony.',
	'form_prop_confirmer_envoi' => 'Potwierdź wysłanie',
	'form_prop_description' => 'Opis/komentarz',
	'form_prop_enregistre' => 'Twoja propozycja została zapisana, pojawi się online po jej zatwierdzeniu przez administratora tej strony.',
	'form_prop_envoyer' => 'Wyślij wiadomość',
	'form_prop_indiquer_email' => 'Proszę wpisać prawidłowy adres e-mail',
	'form_prop_indiquer_nom_site' => 'Proszę wpisać nazwę strony.',
	'form_prop_indiquer_sujet' => 'Proszę wpisać temat',
	'form_prop_message_envoye' => 'Wiadomość wysłana',
	'form_prop_non_enregistre' => 'Twoja propozycja nie została zapisana.',
	'form_prop_sujet' => 'Temat',
	'form_prop_url_site' => 'URL stron\\y', # MODIF
	'forum_non_inscrit' => 'Nie jesteś zarejestrowany, lub adres bądź hasło są nieprawidłowe.',
	'forum_par_auteur' => 'wg @auteur@',
	'forum_titre_erreur' => 'Błąd...',

	// I
	'ical_texte_rss_articles' => 'Plik "backend" artykułów tej strony znajduje się pod adresem:',
	'ical_texte_rss_articles2' => 'Możesz również otrzymać pliki "backend" dla artykułów dla każdego z działów strony:',
	'ical_texte_rss_breves' => 'Istnieje także plik zawierający wszystkie newsy opublikowane na stronie. Precyzując numer działu, otrzymasz newsy opublikowane w tym dziale.',
	'icone_a_suivre' => 'Aktualności',
	'icone_admin_site' => 'Administracja strony',
	'icone_agenda' => 'Kalendarz',
	'icone_aide_ligne' => 'Pomoc',
	'icone_articles' => 'Artykuły',
	'icone_auteurs' => 'Autorzy',
	'icone_brouteur' => 'Menu podręczne',
	'icone_configuration_site' => 'Konfiguracja',
	'icone_configurer_site' => 'Konfiguruj swoją stronę',
	'icone_creer_nouvel_auteur' => 'Utwórz nowego autora',
	'icone_creer_rubrique' => 'Utwórz dział',
	'icone_creer_sous_rubrique' => 'Utwórz poddział',
	'icone_deconnecter' => 'Rozłącz',
	'icone_discussions' => 'Dyskusje',
	'icone_doc_rubrique' => 'Załączniki',
	'icone_ecrire_article' => 'Napisz nowy artykuł',
	'icone_edition_site' => 'Edycja',
	'icone_gestion_langues' => 'Zarządzanie językami',
	'icone_informations_personnelles' => 'Informacje osobiste',
	'icone_interface_complet' => 'cały interfejs',
	'icone_interface_simple' => 'Uproszczony interfejs',
	'icone_maintenance_site' => 'Administracja stroną',
	'icone_messagerie_personnelle' => 'Wiadomości prywatne',
	'icone_repartition_debut' => 'Pokaż dystrybucję od początku',
	'icone_rubriques' => 'Działy',
	'icone_sauver_site' => 'Backup strony',
	'icone_site_entier' => 'Cała strona',
	'icone_sites_references' => 'Zlinkowane strony',
	'icone_statistiques' => 'Statystyki strony',
	'icone_suivi_activite' => 'Prace redakcyjne',
	'icone_suivi_actualite' => 'Rozwój strony',
	'icone_suivi_pettions' => 'Śledź/zarządzaj ogłoszeniami',
	'icone_suivi_revisions' => 'Zmiany artykułów',
	'icone_supprimer_document' => 'Usuń ten dokument',
	'icone_supprimer_image' => 'Usuń ten obrazek',
	'icone_tous_articles' => 'Wszystkie Twoje artykuły',
	'icone_tous_auteur' => 'Wszyscy autorzy',
	'icone_tous_visiteur' => 'Wszyscy odwiedzający',
	'icone_visiter_site' => 'Przejdź do Twojego serwisu',
	'icone_voir_en_ligne' => 'Obejrzyj online',
	'img_indisponible' => 'obrazek niedostępny',
	'impossible' => 'niemożliwe',
	'info_a_suivre' => 'KONTYNUUJ »',
	'info_acces_interdit' => 'Dostęp zabroniony',
	'info_acces_refuse' => 'Brak dostępu',
	'info_action' => 'Akcja: @action@',
	'info_administrer_rubriques' => 'Możesz zarządzać tą działami i jej poddziałami',
	'info_adresse_non_indiquee' => 'Nie podałeś adresu testowego!',
	'info_aide' => 'POMOC:',
	'info_ajouter_mot' => 'Dodaj to słowo kluczowe',
	'info_annonce' => 'ZAWIADOMIENIE',
	'info_annonces_generales' => 'Ogólne ogłoszenia:',
	'info_article_propose' => 'Zaproponowany artykuł',
	'info_article_publie' => 'Artykuł opublikowany',
	'info_article_redaction' => 'Artykuł w trakcie tworzenia',
	'info_article_refuse' => 'Artykuł odrzucony',
	'info_article_supprime' => 'Artykuł usunięty',
	'info_articles' => 'Artykuły',
	'info_articles_a_valider' => 'Artykuły do zatwierdzenia',
	'info_articles_nb' => '@nb@ artykułów',
	'info_articles_proposes' => 'Zaproponowane artykuły',
	'info_articles_un' => '1 artykuł',
	'info_auteurs_nombre' => 'autor(zy):',
	'info_authentification_ftp' => 'Uwierzytelnienie (poprzez FTP).',
	'info_breves_2' => 'newsy',
	'info_breves_nb' => '@nb@ newsów',
	'info_connexion_refusee' => 'Brak połączenia',
	'info_contact_developpeur' => 'Proszę skontaktować się z deweloperem.',
	'info_contenance' => 'Ta strona zawiera:',
	'info_contribution' => 'wpisy na forum', # MODIF
	'info_copyright' => '@spip@ - darmowe oprogramowanie dystrybuowane w oparciu o licencję @lien_gpl@.',
	'info_copyright_doc' => 'Więcej informacji na stronie <a href="@spipnet@">http://www.spip.net</a>.', # MODIF
	'info_copyright_gpl' => 'na licencji GPL',
	'info_cours_edition' => 'Twoje artykuły w trakcie redagowania', # MODIF
	'info_creer_repertoire' => 'Utwórz plik lub katalog o nazwie:',
	'info_creer_repertoire_2' => 'w podkatalogu <b>@repertoire@</b>, a następnie:',
	'info_creer_vignette' => 'generowanie miniaturki',
	'info_deplier' => 'Rozwiń',
	'info_descriptif_nombre' => 'opis(y):',
	'info_description' => 'Opis:',
	'info_description_2' => 'Opis:',
	'info_dimension' => 'Rozmiar:',
	'info_ecire_message_prive' => 'Napisz prywatną wiadomość',
	'info_email_invalide' => 'Nieprawidłowy adres e-mail.',
	'info_en_cours_validation' => 'Twoje artykuły są w trakcie redagowania',
	'info_en_ligne' => 'Teraz online:',
	'info_envoyer_message_prive' => 'Wyślij prywatną wiadomość do tego autora',
	'info_erreur_requete' => 'Błąd zapytania :',
	'info_erreur_squelette2' => 'Żaden szkielet <b>@fichier@</b> nie jest dostępny ...',
	'info_erreur_systeme' => 'Błąd systemu (errno @errsys@)',
	'info_erreur_systeme2' => 'Albo dysk twardy jest pełny albo uszkodzona jest baza danych.<br />
<span style="color:red;">Spróbuj <a href=\'@script@\'>naprawić bazę danych</a>, lub skontaktuj się z administratorem serwera.</span>',
	'info_fini' => 'Zakończono!',
	'info_format_image' => 'Formaty plików obrazków, które mogą być używane do tworzenia minitaturek : @gd_formats@.',
	'info_format_non_defini' => 'format niezdefiniowany',
	'info_grand_ecran' => 'Cały ekran',
	'info_image_aide' => 'POMOC',
	'info_image_process_titre' => 'Sposób generowania miniaturek',
	'info_impossible_lire_page' => '<b>Błąd !</b> Nie można odczytać strony<tt><html>@test_proxy@</html></tt> za pośrednictwem proxy<tt>',
	'info_installation_systeme_publication' => 'Instalacja systemu publikacji...',
	'info_installer_documents' => 'Możesz automatycznie dodawać wszystkie dokumenty znajdujące się w folderze @upload@.',
	'info_installer_ftp' => 'Jako administrator możesz umieszczać (przez FTP) pliki w folderze @upload@, aby później wybierać je bezpośrednio stąd.',
	'info_installer_images' => 'Możesz umieszczać obrazki w formatach JPEG, GIF i PNG.',
	'info_installer_images_dossier' => 'Umieść obrazki w folderze @upload@ aby móc je stąd wybierać.',
	'info_interface_complete' => 'cały interfejs',
	'info_interface_simple' => 'Uproszczony interfejs',
	'info_joindre_document_article' => 'Do tego artykułu możesz załączać dokumenty typu',
	'info_joindre_document_rubrique' => 'Do tego działu możesz dodawać dokumenty typu',
	'info_joindre_documents_article' => 'Do swojego atykułu możesz załączać dokumenty typu:',
	'info_l_article' => 'artykuł',
	'info_la_breve' => 'news',
	'info_la_rubrique' => 'dział',
	'info_langue_principale' => 'Język głównej strony',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pikseli',
	'info_les_auteurs_1' => 'wg @les_auteurs@',
	'info_logo_format_interdit' => 'Dla logo dozwolone są następujące formaty: @formats@.',
	'info_logo_max_poids' => 'Logo może mieć maksymalnie @maxi@ (teraz ma @actuel@).',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'WIADOMOŚĆ',
	'info_message_supprime' => 'WIADOMOŚĆ USUNIĘTA',
	'info_mise_en_ligne' => 'Data publikacji online:',
	'info_modification_parametres_securite' => 'modyfikacja parametrów bezpieczeństwa',
	'info_mois_courant' => 'Bieżący miesiąc:',
	'info_mot_cle_ajoute' => 'Następujące słowo kluczowe dodane zostało do',
	'info_multi_herit' => 'Język domyślny',
	'info_multi_langues_soulignees' => '<u>Podkreślonie języka</u> świadczy o kompletnym przekładzie wszystkich tekstów interfejsu. Jeśli wybierzesz jeden z tych języków, elementy serwisu (daty, formularze) zostaną automatycznie przetłumaczone. W przypadku języków nie-podkreślonych, elementy te ukażą się w głównym języku serwisu.', # MODIF
	'info_multilinguisme' => 'Wielojęzyczny',
	'info_nom_non_utilisateurs_connectes' => 'Twoja nazwa nie pojawia się na liście podłączonych użytkowników.',
	'info_nom_utilisateurs_connectes' => 'Twoje imię występuje na liście podłączonych użytkowników.',
	'info_nombre_en_ligne' => 'Teraz online:',
	'info_non_resultat' => 'Żadnych wyników dla "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Nie korzystasz z wewnętrznej komunikacji tego serwisu.',
	'info_nouveau_message' => 'MASZ NOWĄ WIADOMOŚĆ',
	'info_nouveaux_messages' => 'MASZ @total_messages@ NOWYCH WIADOMOŚCI',
	'info_numero_abbreviation' => 'N° ',
	'info_pense_bete' => 'NOTATKA',
	'info_petit_ecran' => 'Małe okno',
	'info_pixels' => 'piksele',
	'info_plusieurs_mots_trouves' => 'Kilkanaście słów kluczowych zostało znalezionych dla "@cherche_mot@":',
	'info_portfolio_automatique' => 'Automatyczne portfolio:',
	'info_premier_resultat' => '[@debut_limit@ pierwsze wyniki z @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ pierwsze wyniki z @total@]',
	'info_propose_1' => '[@nom_site_spip@] Zatwierdza: @titre@',
	'info_propose_2' => 'Artykuły zatwierdzone
-----------------',
	'info_propose_3' => 'Artykuł "@titre@" został zatwierdzony do publikacji.',
	'info_propose_4' => 'Zostałeś zaproszony do przeglądu i wyrażenia swojej opinii',
	'info_propose_5' => 'w forum, które jest przyporządkowane. Jest ono dostępne pod adresem :',
	'info_publie_01' => 'Artykuł "@titre@" został zatwierdzony przez @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLIKUJE: @titre@',
	'info_publie_2' => 'Artykuł opublikowany
-----------------',
	'info_rechercher' => 'Szukaj',
	'info_rechercher_02' => 'Szukaj:',
	'info_remplacer_vignette' => 'Zamień domyślną miniaturkę na wybrane przez ciebie logo :',
	'info_sans_titre_2' => 'bez tytułu',
	'info_selectionner_fichier' => 'Możesz wybrać plik z folderu @upload@',
	'info_selectionner_fichier_2' => 'Wybierz plik:',
	'info_supprimer_vignette' => 'usuń winietę',
	'info_symbole_bleu' => 'Symbol <b>niebieski</b> oznacza  <b>notatkę</b>: n.p. wiadomość do prywatnego użytku.',
	'info_symbole_jaune' => 'Symbol <b>żółty</b> oznacza <b>zawiadomienie dla wszystkich redaktorów</b>: może być opublikowana przez wszystkich administratorów, i jest widoczna dla wszystkich redaktorów.',
	'info_symbole_vert' => 'Symbol <b>zielony</b> oznacza <b>wiadomości wymieniane z innymi użytkownikami</b> strony.',
	'info_telecharger_nouveau_logo' => 'Załaduj nowe logo:',
	'info_telecharger_ordinateur' => 'Załaduj ze swojego komputera:',
	'info_tous_resultats_enregistres' => '[wszystkie wyniki są zapisane]',
	'info_tout_afficher' => 'Pokaż wszystko',
	'info_travaux_texte' => 'Ten serwis nie jest jeszcze skonfigurowany. Zapraszamy później...',
	'info_travaux_titre' => 'Strona w trakcie budowy',
	'info_trop_resultat' => 'Zbyt dużo rezultatów "@cherche_mot@" ; spróbuj sprecyzować kryteria wyszukiwania.',
	'info_utilisation_messagerie_interne' => 'Używasz wewnętrznej poczty w tym serwisie.',
	'info_valider_lien' => 'zatwierdź ten link',
	'info_verifier_image' => ', proszę się upewnić, czy obrazki zostały przesłane prawidłowo.',
	'info_vignette_defaut' => 'Domyślna winieta',
	'info_vignette_personnalisee' => 'Miniaturka spersonalizowana',
	'info_visite' => 'odwiedziny:',
	'info_vos_rendez_vous' => 'Twoje przyszłe spotkania',
	'infos_vos_pense_bete' => 'Twoje notatki', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Pokazuj tylko ikonki',
	'lien_afficher_texte_icones' => 'POkazuj ikonki i tekst',
	'lien_afficher_texte_seul' => 'Pokazuj tylko tekst',
	'lien_liberer' => 'uwolnij',
	'lien_liberer_tous' => 'uwolnij artykuły', # MODIF
	'lien_nouvea_pense_bete' => 'NOWA NOTATKA',
	'lien_nouveau_message' => 'NOWA WIADOMOŚĆ',
	'lien_nouvelle_annonce' => 'NOWE ZAWIADOMIENIE',
	'lien_petitions' => 'OGŁOSZENIE',
	'lien_popularite' => 'popularność: @popularite@%',
	'lien_racine_site' => 'RDZEŃ STRONY',
	'lien_reessayer' => 'spróbuj ponownie',
	'lien_repondre_message' => 'Odpowiedz na tę wiadomość',
	'lien_supprimer' => 'usuń',
	'lien_tout_afficher' => 'Pokaż wszystko',
	'lien_visite_site' => 'odwiedź stronę',
	'lien_visites' => '@visites@ odwiedzin',
	'lien_voir_auteur' => 'Sprawdź autora',
	'ligne' => 'Linia',
	'login' => 'Połączenie',
	'login_acces_prive' => 'dostęp do obszaru prywatnego',
	'login_autre_identifiant' => 'zaloguj używając innego loginu',
	'login_cookie_accepte' => 'Zmień ustawienia Twojej przeglądarki, aby je akceptowała (przynajmniej dla tej strony).',
	'login_cookie_oblige' => 'Aby móc zalogować się bezpiecznie do tej strony, musicie zaakceptować cookies.',
	'login_deconnexion_ok' => 'Rozłączanie zakończono.',
	'login_erreur_pass' => 'Błąd hasła.',
	'login_espace_prive' => 'obszar prywatny',
	'login_identifiant_inconnu' => 'Login « @login@ » nieznany.',
	'login_login' => 'Login:',
	'login_login2' => 'Login (identyfikator) :', # MODIF
	'login_login_pass_incorrect' => '(Zły login lub hasło).',
	'login_motpasseoublie' => 'zapomniałeś hasła?',
	'login_non_securise' => 'Uwaga ten formularz nie jest bezpieczny.
   Jeśli nie chcesz aby Twoje hasło zostało przechwycone w sieci
   , włącz JavaScript w Twojej przeglądarce i',
	'login_nouvelle_tentative' => 'Nowa próba',
	'login_par_ici' => 'Jesteś zarejestrowany... tędy...',
	'login_pass2' => 'Hasło:',
	'login_preferez_refuser' => '<b>Jeśli wolisz nie korzystać z cookies</b>, jest inna (mniej bezpieczna) metoda do dyspozycji :',
	'login_recharger' => 'przeładuj stronę',
	'login_rester_identifie' => 'Pozostań zalogowany kilka dni',
	'login_retour_public' => 'Powrót do strony publicznej',
	'login_retour_site' => 'Powrót do strony publicznej',
	'login_retoursitepublic' => 'Powrót do strony publicznej',
	'login_sinscrire' => 'rejestracja',
	'login_test_navigateur' => 'test przeglądarki/łącz ponownie',
	'login_verifiez_navigateur' => '(Sprawdź czy Twoja przeglądarka nie zapamiętała hasła...)',

	// M
	'masquer_trad' => 'ukryj tlumaczenia',
	'module_fichiers_langues' => 'Pliki językowe',

	// N
	'navigateur_pas_redirige' => 'Jeśli twoja przeglądarka cię nie przekierowała, kliknij tutaj, żeby kontynuować.',
	'numero' => 'Numer',

	// O
	'occurence' => 'Wystąpienie',
	'onglet_affacer_base' => 'Usuń bazę danych',
	'onglet_auteur' => 'Autor',
	'onglet_contenu_site' => 'Zawartość strony',
	'onglet_evolution_visite_mod' => 'Ewolucja',
	'onglet_fonctions_avances' => 'Funkcje zaawansowane',
	'onglet_informations_personnelles' => 'Informacje osobiste',
	'onglet_interactivite' => 'Interaktywność',
	'onglet_messagerie' => 'Wiadomości',
	'onglet_repartition_rubrique' => 'Rozłożenie działów',
	'onglet_save_restaur_base' => 'Backup/zapisywanie bazy danych',
	'onglet_vider_cache' => 'Opróżnij cache',

	// P
	'pass_choix_pass' => 'Proszę wybrać swoje nowe hasło:',
	'pass_erreur' => 'Błąd',
	'pass_erreur_acces_refuse' => '<b>Błąd:</b> nie masz już dostępu do tej strony.',
	'pass_erreur_code_inconnu' => '<b>Błąd :</b> ten kod nie odpowiada, żadnemu z użytkowników, którzy mają dostęp do tej strony.',
	'pass_erreur_non_enregistre' => '<b>Błąd :</b> adres <tt>@email_oubli@</tt> nie jest zarejestrowany na tej stronie.',
	'pass_erreur_non_valide' => '<b>Błąd :</b> e-mail <tt>@email_oubli@</tt> nie jest prawidłowy!',
	'pass_erreur_probleme_technique' => '<b>Bład :</b> e-mail nie mógł być wysłany z powodu problemów technicznych.',
	'pass_espace_prive_bla' => 'Strefa prywatna tego serwisu jest dostęna
  dla zapisanych użytkowników. Jako zarejestrowany użytkownik,
  będziesz mógł czytać artykuły, które są w trakcie redagowania,
  proponować artykuły i brać udział w dyskusjach na forum.',
	'pass_forum_bla' => 'Chcesz wziąć udział w forum
  zarezerwowanym dla zarejestrowanych użytkowników.',
	'pass_indiquez_cidessous' => 'Wpisz poniżej adres e-mail pod jakim
byłeś zarejestrowany poprzednio.
Otrzymasz e-maila wyjaśniającego jak
możesz odzyskać swój dostęp.',
	'pass_mail_passcookie' => '(to jest automatyczna wiadomość)

Aby odzyskać dostęp do strony
@nom_site_spip@ (@adresse_site@)

Proszę wejść na stronę:

    @sendcookie@

Po wpisaniu nowego hasła
można ponownie połączyć się ze stroną.
',
	'pass_mot_oublie' => 'Zapomniane hasło',
	'pass_nouveau_enregistre' => 'Twoje nowe hasło zostało zapisane.',
	'pass_nouveau_pass' => 'Nowe hasło',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Zapomnienie hasła',
	'pass_quitter_fenetre' => 'Zamknij okno',
	'pass_rappel_login' => 'Przypomnienie : twój identyfikator (login) to « @login@ ».',
	'pass_recevoir_mail' => 'Otrzymasz e-mail wyjaśniający jak możesz odzyskać dostęp do strony.',
	'pass_retour_public' => 'Powrót do strony publicznej',
	'pass_rien_a_faire_ici' => 'Nie ma tu nic do zrobienia.',
	'pass_vousinscrire' => 'Zapisaś się w tym serwisie',
	'precedent' => 'poprzedni',
	'previsualisation' => 'Podgląd',
	'previsualiser' => 'Włącz podgląd',

	// R
	'retour' => 'Powrót',

	// S
	'spip_conforme_dtd' => 'SPIP uznaje ten dokument za zgodny z jego DOCTYPE :',
	'squelette' => 'szkielet',
	'squelette_inclus_ligne' => 'szkielet zainkludowany, linia',
	'squelette_ligne' => 'szkielet, linia',
	'stats_visites_et_popularite' => '@visites@ odwiedzin; popularność: @popularite@',
	'suivant' => 'następny',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Kiedy poznasz interfejs, kliknij na «',
	'texte_actualite_site_2' => 'kompletny interfejs',
	'texte_actualite_site_3' => '» aby uruchomić więcej możliwości.',
	'texte_creation_automatique_vignette' => 'W tym serwisie, uruchomione jest generowanie minitaurek.Jeśli instalujecie za pośrednictwem tego formularza pliki graficzne w formatach @gd_formats@, zostaną one uzupełnione o minitaurkę, o miniaturkę w wielkości maksymalnej: @taille_preview@ pixels.',
	'texte_documents_associes' => 'Następujące dokumenty są związane z artykułem,
    ale nie zostały bezpośrednio do niego
    dołączone. Zależnie od układu stron publicznych,
    będę mogły pojawić się na nich jako załączniki.',
	'texte_erreur_mise_niveau_base' => 'Błąd bazy danych zaistniały w trakcie uaktualniania.
  Obrazek <b>@fichier@</b> nie przeszedł (artykuł @id_article@).
  Zapisz te dane, i spróbuj ponownego uaktualnienia,
a następnie sprawdź czy obrazki pojawiają się zawsze w artykułach.',
	'texte_erreur_visiteur' => 'Próbujesz dostać się do panelu administracyjnego za pomocą loginu, który na to nie pozwala.',
	'texte_inc_auth_1' => 'Jesteś zalogowany za pomocą
  loginu <b>@auth_login@</b>, ale nie istnieje on (już) w bazie danych. 
  Spróbuj się', # MODIF
	'texte_inc_auth_2' => 'połączyć',
	'texte_inc_auth_3' => ', opuszczjąc ewentualnie przeglądarkę
  i włączając ją na powrót.',
	'texte_inc_config' => 'Zmiany dokonane na tych stronach znacząco wpłyną na
 funkcjonowanie Twojego serwisu. Radzimy nie zatwierdzać tych zmian do momentu, w którym nie będziecie
 dobrze obeznani z funkcjonowaniem systemu SPIP. <br /><br /><b>Najbardziej
 zalecamy, poproszenie o dokonanie zmian głównego adminsitratora serwisu.</b>',
	'texte_inc_meta_1' => 'System nie może zapisać plików <code>@fichier@</code>. Jako administrator strony,',
	'texte_inc_meta_2' => 'sprawdź pozwolenia zapisu',
	'texte_inc_meta_3' => 'dla katalogu <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'redakcja w toku',
	'texte_statut_poubelle' => 'do kosza',
	'texte_statut_propose_evaluation' => 'zaproponowany do oceny',
	'texte_statut_publie' => 'opublikowany online',
	'texte_statut_refuse' => 'odrzucony',
	'titre_ajouter_mot_cle' => 'DODAJ SŁOWO KLUCZOWE:',
	'titre_cadre_raccourcis' => 'SKRÓTY :',
	'titre_changer_couleur_interface' => 'Zmiana koloru interfejsu',
	'titre_image_admin_article' => 'Możesz edytować ten artykuł',
	'titre_image_administrateur' => 'Administrator',
	'titre_image_aide' => 'Pomoc do tego elementu',
	'titre_image_auteur_supprime' => 'Autor usunięty',
	'titre_image_redacteur' => 'Redaktor bez dostępu',
	'titre_image_redacteur_02' => 'Redaktor',
	'titre_image_visiteur' => 'Odwiedzający',
	'titre_joindre_document' => 'ZAŁĄCZ DOKUMENT',
	'titre_mots_cles' => 'SŁOWA KLUCZOWE',
	'titre_probleme_technique' => 'Uwaga: problem techniczny (serwer SQL) blokuje dostęp do tej części strony. Dziękujemy za zrozumienie.',
	'titre_publier_document' => 'PUBLIKUJ DOKUMENT W TYM DZIALE',
	'titre_statistiques' => 'Statystyki strony',
	'titre_titre_document' => 'Tytuł dokumentu:',
	'trad_reference' => '(artykuł wzorcowy)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : balise B en aval',
	'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n’existe pas', # MODIF
	'zbug_boucle' => 'pętla',
	'zbug_boucle_recursive_undef' => 'pętla rekursywna nie została zdefiniowana', # MODIF
	'zbug_champ_hors_boucle' => 'Pole @champ@ jest bez pętli',
	'zbug_champ_hors_motif' => 'Pole @champ@ jest poza pętlą @motif@', # MODIF
	'zbug_code' => 'kod',
	'zbug_critere_inconnu' => 'nieznane kryterium @critere@', # MODIF
	'zbug_distant_interdit' => 'operacja niedozwolona w zewnętrznej bazie', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
	'zbug_doublon_table_sans_index' => 'podwójny wpis w tablicy bez indeksu', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@: podwójna definicja', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: brakuje znacznika zamykającego', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Składnia pętli (boucle) nieprawidłowa', # MODIF
	'zbug_erreur_compilation' => 'Błąd kompilacji',
	'zbug_erreur_execution_page' => 'błąd w wykonaniu strony', # MODIF
	'zbug_erreur_filtre' => 'Błąd : filtr <b>« @filtre@ »</b> nie zdefiniowany', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} stosuje się wyłącznie do pętli (FORUMS) i (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Błąd (błędy) w szkielecie',
	'zbug_info_erreur_squelette' => 'Błąd na stronie',
	'zbug_inversion_ordre_inexistant' => 'odwrócenie nieistniejącego uporządkowania', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION bez kryterium {pagination} lub użyta w pętli rekursywnej', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Złe parametry załączenia (include)', # MODIF
	'zbug_profile' => 'Czas przeliczania: @time@',
	'zbug_resultat' => 'wynik',
	'zbug_serveur_indefini' => 'serwer SQL niezdefiniowany', # MODIF
	'zbug_table_inconnue' => 'Tabela SQL « @table@ » nieznana',
	'zxml_connus_attributs' => 'znane atrybuty',
	'zxml_de' => 'z',
	'zxml_inconnu_attribut' => 'atrybut nieznany',
	'zxml_inconnu_balise' => 'znacznik nieznany',
	'zxml_inconnu_entite' => 'nieznana wartość',
	'zxml_inconnu_id' => 'ID nieznany',
	'zxml_mais_de' => 'ale z',
	'zxml_non_conforme' => 'nie jest zgodny',
	'zxml_non_fils' => 'nie jest z',
	'zxml_nonvide_balise' => 'znacznik nie jest pusty',
	'zxml_obligatoire_attribut' => 'nieobecny atrybut obowiązkowy',
	'zxml_succession_fils_incorrecte' => 'niepoprawne dziedziczenie',
	'zxml_survoler' => 'najedź wskaźnikiem aby zobaczyć poprawne',
	'zxml_valeur_attribut' => 'wartość artybutu',
	'zxml_vide_balise' => 'pusty znacznik',
	'zxml_vu' => 'widziany wcześniej'
);

?>
